@@ -87,6 +87,7 @@ class ScanCommand:
         self.detectorVoltage = None
         self.error = None
         self._testWithMocks = True
+        self._completedWl = 0
 
     def execute(self):
         try:
@@ -94,6 +95,7 @@ class ScanCommand:
                 self._controller.move_to_cavity_1()
                 self._controller.get_active_cavity().activate_s2()
                 for wavelength in self.wavelengths:
+                    self._completedWl += 1
                     if self.stopped.is_set():
                         return
                     logger.info('going to wavelength {}'.format(wavelength))
@@ -147,7 +149,8 @@ class ScanCommand:
                             'current_X': self.currentX,
                             'current_y': self.currentY,
                             'error': self.error,
-                            'detector_voltage': self.detectorVoltage},
+                            'detector_voltage': self.detectorVoltage,
+                            'completed': self._completedWl/len(self.wavelengths)},
                 'results': self.results}
 
 
